Name:           PurC
Version:        0.9.6
Release:        1%{?dist}
Summary:        The prime HVML interpreter for C Language

License:        LGPLv3 AND GPLv3 AND Public Domain
URL:            https://github.com/HVML/PurC
Source0:        %{url}/archive/ver-%{version}/%{name}-ver-%{version}.tar.gz
Patch0:         correct-timezone-path.patch

BuildRequires:  bc
BuildRequires:  bison
BuildRequires:  bison-devel
BuildRequires:  bison-runtime
BuildRequires:  cmake
BuildRequires:  flex
BuildRequires:  flex-devel
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  glib-devel
BuildRequires:  gperf
BuildRequires:  gmock-devel
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtest-devel
# ICU data needs to be packaged
# to get features that use ICU
#BuildRequires:  icu
#BuildRequires:  libicu-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libnotify-devel
BuildRequires:  libpsl-devel
BuildRequires:  libsecret-devel
BuildRequires:  libsoup-devel
BuildRequires:  libuuid-devel
BuildRequires:  libxml2-devel
# mysqlclient from mariadb does not
# seem like it can be used
#BuildRequires:  mariadb-devel
BuildRequires:  ncurses-devel
BuildRequires:  openssl-devel
BuildRequires:  python-devel
BuildRequires:  sqlite-devel
BuildRequires:  valgrind-devel
BuildRequires:  vim-minimal
BuildRequires:  xdg-utils
BuildRequires:  zlib-devel
Requires:       xdg-utils

%description
PurC is the acronym of the Prime HVML inteRpreter for C language.
It is also the abbreviation of Purring Cat, while Purring Cat is
the nickname and the mascot of HVML.

The goal of PurC is to implement all features defined by HVML
Specifiction V1.0 and all predefined dynamic objects defined by
HVML Predefined Variables V1.0 in C language.

You can use PurC to run an HVML program or an HVML app by using
the command line tool purc, or use PurC as a library to build your
own HVML interpreter.

We release PurC under LGPLv3, so it is free for commercial use
if you follow the conditions and terms of LGPLv3.

%package devel
Summary:        The prime HVML interpreter for C Language
Requires:       %{name}%{?_isa} = %{version}-%{release}
Provides:       libcsseng
Provides:       libdomruler
Provides:       libpurc

%description devel
Development headers and libraries for PurC

%prep
%autosetup -n %{name}-ver-%{version} -p 1
rm -r deprecated
# remove bundled packages
rm -r Source/ThirdParty
# Do not look for bundled packages
sed -i '/add_subdirectory(ThirdParty\/xdgmime)/d' Source/CMakeLists.txt
sed -i '/add_subdirectory(ThirdParty\/gtest)/d' Source/CMakeLists.txt

%build
%cmake -B purc-build -DCMAKE_BUILD_TYPE=RelWithDebInfo -DPORT=Linux \
-DENABLE_CHINESE_NAMES=ON -DENABLE_REMOTE_FETCHER=OFF \
-DINSTALL_GTEST=OFF -DENABLE_API_TESTS=ON

cd purc-build
%make_build
cd ..

%install
cd purc-build
%make_install
cd ..

%check
# uname seems to fail in the cloud
uname -s
uname -n
uname -r
uname -v
uname -m
uname -p
uname -i
uname -o

# Check logs for test errors

cd purc-build
bash run_all_tests.sh
cd ..

%files
%{_bindir}/purc
%dir %{_libdir}/purc-0.9
%{_libdir}/purc-0.9/libpurc-dvobj-FS.so
%{_libdir}/purc-0.9/libpurc-dvobj-MATH.so
%{_libdir}/libcsseng.so.%{version}
%{_libdir}/libdomruler.so.%{version}
%{_libdir}/libpurc.so.%{version}
%{_libdir}/libcsseng.so.0
%{_libdir}/libdomruler.so.0
%{_libdir}/libpurc.so.0
%license COPYING.LESSER
%doc README.md
%doc RELEASE-NOTES.md
%doc README-zh.md

%files devel
%dir %{_includedir}/domruler
%{_includedir}/domruler/*.h
%dir %{_includedir}/csseng
%{_includedir}/csseng/*.h
%dir %{_includedir}/purc
%{_includedir}/purc/*.h
%{_libdir}/libcsseng.so
%{_libdir}/libdomruler.so
%{_libdir}/libpurc.so
%{_libdir}/pkgconfig/csseng.pc
%{_libdir}/pkgconfig/domruler.pc
%{_libdir}/pkgconfig/purc.pc

%changelog
* Mon Mar 06 2023 Benson Muite <benson_muite@emailplus.org> 0.9.6-1
- Update to new version

* Mon Jan 09 2023 Benson Muite <benson_muite@emailplus.org> 0.9.5-1
- Update to new version

* Fri Dec 02 2022 Benson Muite <benson_muite@emailplus.org> 0.9.2-1
- Initial packaging
